@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,21 +66,6 @@ import java.util.ListResourceBundle;
 public class FormatData_nn extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_MonthNames = new String[] {
-               "januar",
-               "februar",
-               "mars",
-               "april",
-               "mai",
-               "juni",
-               "juli",
-               "august",
-               "september",
-               "oktober",
-               "november",
-               "desember",
-               "",
-            };
         final String[] metaValue_MonthAbbreviations = new String[] {
                "jan.",
                "feb.",
@@ -100,21 +81,6 @@ public class FormatData_nn extends ListResourceBundle {
                "des.",
                "",
             };
-        final String[] metaValue_MonthNarrows = new String[] {
-               "J",
-               "F",
-               "M",
-               "A",
-               "M",
-               "J",
-               "J",
-               "A",
-               "S",
-               "O",
-               "N",
-               "D",
-               "",
-            };
         final String[] metaValue_DayNames = new String[] {
                "s\u00f8ndag",
                "m\u00e5ndag",
@@ -133,38 +99,53 @@ public class FormatData_nn extends ListResourceBundle {
                "fr.",
                "la.",
             };
-        final String[] metaValue_DayNarrows = new String[] {
-               "S",
-               "M",
-               "T",
-               "O",
-               "T",
-               "F",
-               "L",
-            };
-        final String[] metaValue_QuarterNames = new String[] {
-               "1. kvartal",
-               "2. kvartal",
-               "3. kvartal",
-               "4. kvartal",
-            };
-        final String[] metaValue_QuarterAbbreviations = new String[] {
-               "K1",
-               "K2",
-               "K3",
-               "K4",
+        final String[] metaValue_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
             };
         final String[] metaValue_AmPmMarkers = new String[] {
                "formiddag",
                "ettermiddag",
+               "midnatt",
+               "",
+               "p\u00e5 morgenen",
+               "p\u00e5 formiddagen",
+               "p\u00e5 ettermiddagen",
+               "",
+               "p\u00e5 kvelden",
+               "",
+               "p\u00e5 natten",
+               "",
             };
         final String[] metaValue_narrow_AmPmMarkers = new String[] {
                "f.m.",
                "e.m.",
+               "mn.",
+               "",
+               "mg.",
+               "fm.",
+               "em.",
+               "",
+               "kv.",
+               "",
+               "nt.",
+               "",
             };
-        final String[] metaValue_long_Eras = new String[] {
-               "f.Kr.",
-               "e.Kr.",
+        final String[] metaValue_abbreviated_AmPmMarkers = new String[] {
+               "f.m.",
+               "e.m.",
+               "midn.",
+               "",
+               "morg.",
+               "form.",
+               "etterm.",
+               "",
+               "kveld",
+               "",
+               "natt",
+               "",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "'kl'. HH:mm:ss zzzz",
@@ -172,12 +153,6 @@ public class FormatData_nn extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d. MMMM y G",
                "d. MMMM y G",
@@ -190,25 +165,21 @@ public class FormatData_nn extends ListResourceBundle {
                "d. MMM y GGGG",
                "d.M.y GGGG",
             };
-        final String metaValue_calendarname_gregorian = "gregoriansk kalender";
         final Object[][] data = new Object[][] {
-            { "MonthNames", metaValue_MonthNames },
-            { "field.year", "\u00e5r" },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.QuarterNames", metaValue_QuarterNames },
-            { "roc.MonthNarrows", metaValue_MonthNarrows },
+            { "TimePatterns", metaValue_TimePatterns },
             { "calendarname.islamic-civil", "islamsk sivil kalender" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "narrow.Eras", metaValue_long_Eras },
-            { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "timezone.regionFormat.standard", "normaltid \u2013 {0}" },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "calendarname.japanese", "japansk kalender" },
-            { "japanese.MonthNames", metaValue_MonthNames },
+            { "abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations",
                 new String[] {
                     "s\u00f8n",
@@ -221,11 +192,20 @@ public class FormatData_nn extends ListResourceBundle {
                 }
             },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "long.Eras", metaValue_long_Eras },
-            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
+            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
+            { "long.Eras",
+                new String[] {
+                    "f.Kr.",
+                    "e.Kr.",
+                }
+            },
+            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.MonthNames", metaValue_MonthNames },
+            { "field.weekday", "vekedag" },
             { "DateTimePatterns",
                 new String[] {
                     "{1} {0}",
@@ -252,44 +232,50 @@ public class FormatData_nn extends ListResourceBundle {
                     "",
                 }
             },
-            { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_DayNames },
-            { "field.minute", "minutt" },
-            { "field.era", "tidsalder" },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "f.m./e.m." },
-            { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "calendarname.roc", "kalender for Republikken Kina" },
+            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "japanese.DayNames", metaValue_DayNames },
+            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNames", metaValue_DayNames },
             { "field.month", "m\u00e5nad" },
-            { "field.second", "sekund" },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "field.week", "veke" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "calendarname.islamic", "islamsk kalender" },
-            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "standalone.MonthAbbreviations",
+            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "timezone.regionFormat.daylight", "sommartid \u2013 {0}" },
+            { "DatePatterns",
                 new String[] {
-                    "jan",
-                    "feb",
-                    "mar",
-                    "apr",
-                    "mai",
-                    "jun",
-                    "jul",
-                    "aug",
-                    "sep",
-                    "okt",
-                    "nov",
-                    "des",
-                    "",
+                    "EEEE d. MMMM y",
+                    "d. MMMM y",
+                    "d. MMM y",
+                    "dd.MM.y",
+                }
+            },
+            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:n = 1" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0\u00a0%",
+                    "#,##0.00\u00a0\u00a4",
                 }
             },
-            { "timezone.regionFormat", "tidssone for {0}" },
             { "long.CompactNumberPatterns",
                 new String[] {
                     "",
@@ -309,75 +295,10 @@ public class FormatData_nn extends ListResourceBundle {
                     "{one:000' 'billion other:000' 'billionar}",
                 }
             },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "tidssone" },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "Eras", metaValue_long_Eras },
-            { "roc.DayNames", metaValue_DayNames },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "field.weekday", "vekedag" },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "field.week", "veke" },
-            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "timezone.regionFormat.daylight", "sumartid \u2013 {0}" },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE d. MMMM y",
-                    "d. MMMM y",
-                    "d. MMM y",
-                    "dd.MM.y",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
-            { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
-            { "field.hour", "time" },
-            { "calendarname.buddhist", "buddhistisk kalender" },
-            { "standalone.MonthNames", metaValue_MonthNames },
-            { "latn.NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0\u00a0%",
-                    "#,##0.00\u00a0\u00a4",
-                }
-            },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "japanese.DayNarrows", metaValue_DayNarrows },
-            { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
-            { "calendarname.gregory", metaValue_calendarname_gregorian },
+            { "roc.abbreviated.AmPmMarkers", metaValue_abbreviated_AmPmMarkers },
         };
         return data;
     }
